################################################################################
#
#DATANAME IBIS-PICSIT - EVENTS - SOURCE SPECTRUM
#
#DESCRIPTION
# Contains a PI spectrum obtained from PICsIT events/spectral imaging data
# that can be read with XSPEC.
#
#TEMPLATE PICS-EVTS-SPE
#
#CONTENT BINARY TABLE
#
#REMARKS
# The value of the PICSMODE keyword can either be SPECTRAL IMAGING or
# PHOTON-BY-PHOTON.
#.
# The value of the HIS_TYPE keyword can either be SINGLE or MULTIPLE.
#
#RP obs/scw
#DB No
#V1
#
#CHANGES
# 2.0   : Template creation
# 2.1   : Changed value of FILTER and OBJECT from '' to String
# 2.1.3 : Added missing ISDCLEVL, CREATOR, CONFIGUR and DATE keywords
#       : Removed NAXIS2 keyword
# 2.2.1 : Added units to the RATE, SYS_ERR and STAT_ERR columns
# 3.0   : Renamed template (previously PICS-SGLE-SPE)
#       : Added SOURCEID, PICSMODE and HIS_TYPE keywords
# 3.4   : Changed CHANTYPE keyword value from PHA to PI
#       : Set DETCHANS, TLMIN1 and TLMAX1 keyword values to Integer
# 3.4.2 : Added MJDREF, TIMESYS, TIMEUNIT and TIMEREF keywords
#       : Added REVOL, SWID, SW_TYPE, SWBOUND, OBTSTART and OBTEND keywords
#       : Added TSTART, TSTOP, TFIRST, TLAST and TELAPSE keywords
#       : Added ONTIME and DEADC keywords
# 4.3   : Removed FILTER and OBJECT keywords (SPR-01233)
# 6.5   : Replaced HDUVERS1 by HDUVERS with value of '1.2.0' (SPR-02602)
#
################################################################################
XTENSION	BINTABLE	/ Binary table extension
EXTNAME		PICS-EVTS-SPE	/ Extension name
EXTREL		'6.5'		/ ISDC release number
BASETYPE	DAL_TABLE	/ Data Access Layer base type
TELESCOP	INTEGRAL	/ Telescope or mission name
ORIGIN		ISDC		/ Origin of FITS file
INSTRUME	IBIS		/ Instrument name
DETNAM		PICsIT		/ Name of the detector layer
ISDCLEVL	SPE		/ ISDC level of data processing
CREATOR		String		/ Program that created this FITS file
CONFIGUR	String		/ Software configuration
DATE		UTC_format	/ FITS file creation date
MJDREF		51544.0		/ Modified Julian Date of origin
TIMESYS		TT		/ Time frame system
TIMEUNIT	d		/ Time unit
TIMEREF		LOCAL		/ Time reference frame
REVOL		Integer		/ Revolution number
SWID		String		/ Science Window identifier
SW_TYPE		String		/ Type of the Science Window
SWBOUND		String		/ Reason for Science Window ending
OBTSTART	OBT_format	/ OBT of the start of the Science Window
OBTEND		OBT_format	/ OBT of the end of the Science Window
TSTART		Real		/ Start time of the Science Window
TSTOP		Real		/ End time of the Science Window
TFIRST		Real		/ Time of the first data element
TLAST		Real		/ Time of the last data element
TELAPSE		Real		/ [s] Total elapsed time of the data
ONTIME		Real		/ [s] Sum of good time intervals
DEADC		Real		/ Dead-time correction factor
EXPOSURE	Real		/ [s] Effective exposure time
HDUCLASS	OGIP		/ Format conforms mostly to OGIP standards
HDUCLAS1	SPECTRUM	/ Dataset contains a spectrum
HDUVERS		'1.2.0'		/ Version of format
HDUCLAS2	TOTAL		/ 2nd subclass of OGIP classification
HDUCLAS3	COUNT		/ 3rd subclass of OGIP classification
DETCHANS	Integer		/ Total number of channels
CHANTYPE	PI		/ Channel in instrumental unit (PHA)
TLMIN1		Integer		/ Channel number of first channel
TLMAX1		Integer		/ Channel number of last channel
AREASCAL	1		/ Area scaling factor
BACKSCAL	1		/ Background scaling factor
CORRSCAL	0		/ Correction scaling factor
BACKFILE	NONE		/ Background file
CORRFILE	NONE		/ Correction file
RESPFILE	NONE		/ Redistribution matrix file (RMF)
ANCRFILE	NONE		/ Ancillary response file (ARF)
SOURCEID	String		/ ISDC unique source identifier
NAME		String		/ One commonly used name for the source
PICSMODE	String		/ Mode of the PICsIT detector layer
HIS_TYPE	String		/ Type of histogrammed data
	TTYPE#	CHANNEL		/ Channel number
	TFORM#	1I		/ Format of column CHANNEL
	TTYPE#	RATE		/ Countrate in the given channel
	TFORM#	1E		/ Format of column RATE
	TUNIT#	count/s		/ Unit of column RATE
	TTYPE#	SYS_ERR		/ Systematic error
	TFORM#	1E		/ Format of column SYS_ERR
	TUNIT#	count/s		/ Unit of column SYS_ERR
	TTYPE#	STAT_ERR	/ Statistical error
	TFORM#	1E		/ Format of column STAT_ERR
	TUNIT#	count/s		/ Unit of column STAT_ERR
	TTYPE#	QUALITY		/ Quality flag
	TFORM#	1I		/ Format of column QUALITY
	TTYPE#	GROUPING	/ Grouping flag
	TFORM#	1I		/ Format of column GROUPING
